=== modified file 'breezy/bzr/transform.py'
--- breezy/bzr/transform.py	2020-07-07 22:21:51 +0000
+++ breezy/bzr/transform.py	2020-07-20 02:02:23 +0000
@@ -37,7 +37,6 @@
 
 from ..i18n import gettext
 from ..mutabletree import MutableTree
-from ..sixish import text_type, viewvalues, viewitems
 from ..transform import (
     ROOT_PARENT,
     _FileMover,
@@ -158,7 +157,7 @@
         irrelevant.
 
         """
-        new_roots = [k for k, v in viewitems(self._new_parent)
+        new_roots = [k for k, v in self._new_parent.items()
                      if v == ROOT_PARENT]
         if len(new_roots) < 1:
             return
@@ -293,7 +292,7 @@
         file_id = self.tree_file_id(trans_id)
         if file_id is not None:
             return file_id
-        for key, value in viewitems(self._non_present_ids):
+        for key, value in self._non_present_ids.items():
             if value == trans_id:
                 return key
 
@@ -405,7 +404,7 @@
     def _unversioned_parents(self, by_parent):
         """If parent directories are versioned, children must be versioned."""
         conflicts = []
-        for parent_id, children in viewitems(by_parent):
+        for parent_id, children in by_parent.items():
             if parent_id == ROOT_PARENT:
                 continue
             if self.final_is_versioned(parent_id):
@@ -467,7 +466,7 @@
         conflicts = []
         if (self._new_name, self._new_parent) == ({}, {}):
             return conflicts
-        for children in viewvalues(by_parent):
+        for children in by_parent.values():
             name_ids = []
             for child_tid in children:
                 name = self.final_name(child_tid)
@@ -493,7 +492,7 @@
     def _parent_type_conflicts(self, by_parent):
         """Children must have a directory parent"""
         conflicts = []
-        for parent_id, children in viewitems(by_parent):
+        for parent_id, children in by_parent.items():
             if parent_id == ROOT_PARENT:
                 continue
             no_children = True
@@ -865,17 +864,17 @@
         """
         from .. import bencode
         new_name = {k.encode('utf-8'): v.encode('utf-8')
-                    for k, v in viewitems(self._new_name)}
+                    for k, v in self._new_name.items()}
         new_parent = {k.encode('utf-8'): v.encode('utf-8')
-                      for k, v in viewitems(self._new_parent)}
+                      for k, v in self._new_parent.items()}
         new_id = {k.encode('utf-8'): v
-                  for k, v in viewitems(self._new_id)}
+                  for k, v in self._new_id.items()}
         new_executability = {k.encode('utf-8'): int(v)
-                             for k, v in viewitems(self._new_executability)}
+                             for k, v in self._new_executability.items()}
         tree_path_ids = {k.encode('utf-8'): v.encode('utf-8')
-                         for k, v in viewitems(self._tree_path_ids)}
+                         for k, v in self._tree_path_ids.items()}
         non_present_ids = {k: v.encode('utf-8')
-                           for k, v in viewitems(self._non_present_ids)}
+                           for k, v in self._non_present_ids.items()}
         removed_contents = [trans_id.encode('utf-8')
                             for trans_id in self._removed_contents]
         removed_id = [trans_id.encode('utf-8')
@@ -893,7 +892,7 @@
             }
         yield serializer.bytes_record(bencode.bencode(attribs),
                                       ((b'attribs',),))
-        for trans_id, kind in sorted(viewitems(self._new_contents)):
+        for trans_id, kind in sorted(self._new_contents.items()):
             if kind == 'file':
                 with open(self._limbo_name(trans_id), 'rb') as cur_file:
                     lines = cur_file.readlines()
@@ -920,18 +919,18 @@
         attribs = bencode.bdecode(content)
         self._id_number = attribs[b'_id_number']
         self._new_name = {k.decode('utf-8'): v.decode('utf-8')
-                          for k, v in viewitems(attribs[b'_new_name'])}
+                          for k, v in attribs[b'_new_name'].items()}
         self._new_parent = {k.decode('utf-8'): v.decode('utf-8')
-                            for k, v in viewitems(attribs[b'_new_parent'])}
+                            for k, v in attribs[b'_new_parent'].items()}
         self._new_executability = {
             k.decode('utf-8'): bool(v)
-            for k, v in viewitems(attribs[b'_new_executability'])}
+            for k, v in attribs[b'_new_executability'].items()}
         self._new_id = {k.decode('utf-8'): v
-                        for k, v in viewitems(attribs[b'_new_id'])}
-        self._r_new_id = {v: k for k, v in viewitems(self._new_id)}
+                        for k, v in attribs[b'_new_id'].items()}
+        self._r_new_id = {v: k for k, v in self._new_id.items()}
         self._tree_path_ids = {}
         self._tree_id_paths = {}
-        for bytepath, trans_id in viewitems(attribs[b'_tree_path_ids']):
+        for bytepath, trans_id in attribs[b'_tree_path_ids'].items():
             path = bytepath.decode('utf-8')
             trans_id = trans_id.decode('utf-8')
             self._tree_path_ids[path] = trans_id
@@ -943,7 +942,7 @@
             for trans_id in attribs[b'_removed_contents'])
         self._non_present_ids = {
             k: v.decode('utf-8')
-            for k, v in viewitems(attribs[b'_non_present_ids'])}
+            for k, v in attribs[b'_non_present_ids'].items()}
         for ((trans_id, kind),), content in records:
             trans_id = trans_id.decode('utf-8')
             kind = kind.decode('ascii')
@@ -1050,7 +1049,7 @@
         if self._tree is None:
             return
         try:
-            limbo_paths = list(viewvalues(self._limbo_files))
+            limbo_paths = list(self._limbo_files.values())
             limbo_paths.extend(self._possibly_stale_limbo_files)
             limbo_paths.sort(reverse=True)
             for path in limbo_paths:
@@ -1450,8 +1449,8 @@
                             in (trans_id, None)):
                         use_direct_path = True
                 else:
-                    for l_filename, l_trans_id in viewitems(
-                            self._limbo_children_names[parent]):
+                    for l_filename, l_trans_id in (
+                            self._limbo_children_names[parent].items()):
                         if l_trans_id == trans_id:
                             continue
                         if l_filename.lower() == filename.lower():
@@ -1491,7 +1490,7 @@
         removed_tree_ids = set((self.tree_file_id(trans_id) for trans_id in
                                 self._removed_id))
         active_tree_ids = all_ids.difference(removed_tree_ids)
-        for trans_id, file_id in viewitems(self._new_id):
+        for trans_id, file_id in self._new_id.items():
             if file_id in active_tree_ids:
                 path = self._tree.id2path(file_id)
                 old_trans_id = self.trans_id_tree_path(path)
@@ -1561,7 +1560,7 @@
 
         If inventory_delta is None, no inventory delta generation is performed.
         """
-        tree_paths = sorted(viewitems(self._tree_path_ids), reverse=True)
+        tree_paths = sorted(self._tree_path_ids.items(), reverse=True)
         with ui.ui_factory.nested_progress_bar() as child_pb:
             for num, (path, trans_id) in enumerate(tree_paths):
                 # do not attempt to move root into a subdirectory of itself.
@@ -1646,7 +1645,7 @@
         #       problems. (we could observe start time, and finish time, and if
         #       it is less than eg 10% overhead, add a sleep call.)
         paths = FinalPaths(self)
-        for trans_id, observed in viewitems(self._observed_sha1s):
+        for trans_id, observed in self._observed_sha1s.items():
             path = paths.get_path(trans_id)
             self._tree._observed_sha1(path, observed)
 
@@ -1862,7 +1861,7 @@
         tree_ids = set(self._transform._tree.all_file_ids())
         tree_ids.difference_update(self._transform.tree_file_id(t)
                                    for t in self._transform._removed_id)
-        tree_ids.update(viewvalues(self._transform._new_id))
+        tree_ids.update(self._transform._new_id.values())
         return tree_ids
 
     def all_versioned_paths(self):
@@ -2041,7 +2040,7 @@
                 executable = None
             if kind == 'symlink':
                 link_or_sha1 = os.readlink(limbo_name)
-                if not isinstance(link_or_sha1, text_type):
+                if not isinstance(link_or_sha1, str):
                     link_or_sha1 = link_or_sha1.decode(osutils._fs_enc)
         executable = tt._new_executability.get(trans_id, executable)
         return kind, size, executable, link_or_sha1

=== modified file 'breezy/git/transform.py'
--- breezy/git/transform.py	2020-07-06 01:43:04 +0000
+++ breezy/git/transform.py	2020-07-20 02:02:23 +0000
@@ -25,7 +25,6 @@
 from .. import errors, multiparent, osutils, trace, ui, urlutils
 from ..i18n import gettext
 from ..mutabletree import MutableTree
-from ..sixish import viewitems, viewvalues
 from ..transform import (
     TreeTransform,
     _TransformResults,
@@ -142,7 +141,7 @@
         irrelevant.
 
         """
-        new_roots = [k for k, v in viewitems(self._new_parent)
+        new_roots = [k for k, v in self._new_parent.items()
                      if v == ROOT_PARENT]
         if len(new_roots) < 1:
             return
@@ -277,7 +276,7 @@
         file_id = self.tree_file_id(trans_id)
         if file_id is not None:
             return file_id
-        for key, value in viewitems(self._non_present_ids):
+        for key, value in self._non_present_ids.items():
             if value == trans_id:
                 return key
 
@@ -389,7 +388,7 @@
     def _unversioned_parents(self, by_parent):
         """If parent directories are versioned, children must be versioned."""
         conflicts = []
-        for parent_id, children in viewitems(by_parent):
+        for parent_id, children in by_parent.items():
             if parent_id == ROOT_PARENT:
                 continue
             if self.final_is_versioned(parent_id):
@@ -451,7 +450,7 @@
         conflicts = []
         if (self._new_name, self._new_parent) == ({}, {}):
             return conflicts
-        for children in viewvalues(by_parent):
+        for children in by_parent.values():
             name_ids = []
             for child_tid in children:
                 name = self.final_name(child_tid)
@@ -477,7 +476,7 @@
     def _parent_type_conflicts(self, by_parent):
         """Children must have a directory parent"""
         conflicts = []
-        for parent_id, children in viewitems(by_parent):
+        for parent_id, children in by_parent.items():
             if parent_id == ROOT_PARENT:
                 continue
             no_children = True
@@ -849,17 +848,17 @@
         """
         from .. import bencode
         new_name = {k.encode('utf-8'): v.encode('utf-8')
-                    for k, v in viewitems(self._new_name)}
+                    for k, v in self._new_name.items()}
         new_parent = {k.encode('utf-8'): v.encode('utf-8')
-                      for k, v in viewitems(self._new_parent)}
+                      for k, v in self._new_parent.items()}
         new_id = {k.encode('utf-8'): v
-                  for k, v in viewitems(self._new_id)}
+                  for k, v in self._new_id.items()}
         new_executability = {k.encode('utf-8'): int(v)
-                             for k, v in viewitems(self._new_executability)}
+                             for k, v in self._new_executability.items()}
         tree_path_ids = {k.encode('utf-8'): v.encode('utf-8')
-                         for k, v in viewitems(self._tree_path_ids)}
+                         for k, v in self._tree_path_ids.items()}
         non_present_ids = {k: v.encode('utf-8')
-                           for k, v in viewitems(self._non_present_ids)}
+                           for k, v in self._non_present_ids.items()}
         removed_contents = [trans_id.encode('utf-8')
                             for trans_id in self._removed_contents]
         removed_id = [trans_id.encode('utf-8')
@@ -877,7 +876,7 @@
             }
         yield serializer.bytes_record(bencode.bencode(attribs),
                                       ((b'attribs',),))
-        for trans_id, kind in sorted(viewitems(self._new_contents)):
+        for trans_id, kind in sorted(self._new_contents.items()):
             if kind == 'file':
                 with open(self._limbo_name(trans_id), 'rb') as cur_file:
                     lines = cur_file.readlines()
@@ -904,18 +903,18 @@
         attribs = bencode.bdecode(content)
         self._id_number = attribs[b'_id_number']
         self._new_name = {k.decode('utf-8'): v.decode('utf-8')
-                          for k, v in viewitems(attribs[b'_new_name'])}
+                          for k, v in attribs[b'_new_name'].items()}
         self._new_parent = {k.decode('utf-8'): v.decode('utf-8')
-                            for k, v in viewitems(attribs[b'_new_parent'])}
+                            for k, v in attribs[b'_new_parent'].items()}
         self._new_executability = {
             k.decode('utf-8'): bool(v)
-            for k, v in viewitems(attribs[b'_new_executability'])}
+            for k, v in attribs[b'_new_executability'].items()}
         self._new_id = {k.decode('utf-8'): v
-                        for k, v in viewitems(attribs[b'_new_id'])}
-        self._r_new_id = {v: k for k, v in viewitems(self._new_id)}
+                        for k, v in attribs[b'_new_id'].items()}
+        self._r_new_id = {v: k for k, v in self._new_id.items()}
         self._tree_path_ids = {}
         self._tree_id_paths = {}
-        for bytepath, trans_id in viewitems(attribs[b'_tree_path_ids']):
+        for bytepath, trans_id in attribs[b'_tree_path_ids'].items():
             path = bytepath.decode('utf-8')
             trans_id = trans_id.decode('utf-8')
             self._tree_path_ids[path] = trans_id
@@ -927,7 +926,7 @@
             for trans_id in attribs[b'_removed_contents'])
         self._non_present_ids = {
             k: v.decode('utf-8')
-            for k, v in viewitems(attribs[b'_non_present_ids'])}
+            for k, v in attribs[b'_non_present_ids'].items()}
         for ((trans_id, kind),), content in records:
             trans_id = trans_id.decode('utf-8')
             kind = kind.decode('ascii')
@@ -1034,7 +1033,7 @@
         if self._tree is None:
             return
         try:
-            limbo_paths = list(viewvalues(self._limbo_files))
+            limbo_paths = list(self._limbo_files.values())
             limbo_paths.extend(self._possibly_stale_limbo_files)
             limbo_paths.sort(reverse=True)
             for path in limbo_paths:
@@ -1432,8 +1431,8 @@
                             in (trans_id, None)):
                         use_direct_path = True
                 else:
-                    for l_filename, l_trans_id in viewitems(
-                            self._limbo_children_names[parent]):
+                    for l_filename, l_trans_id in (
+                            self._limbo_children_names[parent].items()):
                         if l_trans_id == trans_id:
                             continue
                         if l_filename.lower() == filename.lower():
@@ -1520,7 +1519,7 @@
 
         If inventory_delta is None, no inventory delta generation is performed.
         """
-        tree_paths = sorted(viewitems(self._tree_path_ids), reverse=True)
+        tree_paths = sorted(self._tree_path_ids.items(), reverse=True)
         with ui.ui_factory.nested_progress_bar() as child_pb:
             for num, (path, trans_id) in enumerate(tree_paths):
                 # do not attempt to move root into a subdirectory of itself.

=== modified file 'breezy/tests/per_repository/test_commit_builder.py'
--- breezy/tests/per_repository/test_commit_builder.py	2020-06-28 23:25:21 +0000
+++ breezy/tests/per_repository/test_commit_builder.py	2020-07-20 02:02:23 +0000
@@ -26,7 +26,6 @@
     revision as _mod_revision,
     tests,
     )
-from breezy.sixish import PY3
 from breezy.tree import TreeChange
 from breezy.bzr import (
     inventorytree,
@@ -823,8 +822,6 @@
                           revprops={'invalid': u'property\rwith\r\ninvalid chars'})
 
     def test_get_commit_builder_with_surrogateescape(self):
-        if not PY3:
-            self.skipTest('python 2 does not have surrogateescape')
         tree = self.make_branch_and_tree(".")
         with tree.lock_write():
             builder = tree.branch.get_commit_builder([], revprops={

=== modified file 'breezy/tests/per_workingtree/test_transform.py'
--- breezy/tests/per_workingtree/test_transform.py	2020-07-07 22:24:22 +0000
+++ breezy/tests/per_workingtree/test_transform.py	2020-07-20 02:02:23 +0000
@@ -48,9 +48,6 @@
     file_kind,
     pathjoin,
 )
-from ...sixish import (
-    text_type,
-    )
 from .. import (
     features,
     TestSkipped,
@@ -897,7 +894,7 @@
         raw_conflicts = resolve_conflicts(tt)
         cooked_conflicts = cook_conflicts(raw_conflicts, tt)
         tt.finalize()
-        conflicts_s = [text_type(c) for c in cooked_conflicts]
+        conflicts_s = [str(c) for c in cooked_conflicts]
         self.assertEqual(len(cooked_conflicts), len(conflicts_s))
         self.assertEqual(conflicts_s[0], 'Conflict adding file dorothy.  '
                                          'Moved existing file to '

=== modified file 'breezy/transform.py'
--- breezy/transform.py	2020-07-18 23:14:00 +0000
+++ breezy/transform.py	2020-07-20 02:02:23 +0000
@@ -218,7 +218,7 @@
         Only new paths and parents of tree files with assigned ids are used.
         """
         by_parent = {}
-        items = list(viewitems(self._new_parent))
+        items = list(self._new_parent.items())
         items.extend((t, self.final_parent(t))
                      for t in list(self._tree_id_paths))
         for trans_id, parent_id in items:

